.style_poCheckboxLabel__2IHB4{font-family:"Source Sans Pro",sans-serif;display:inline-block;padding-right:10px;white-space:nowrap}.style_poCheckboxSpan__ltXcy{vertical-align:middle}.style_poCheckbox__3Q56z{font-size:16px;font-style:normal;-webkit-font-feature-settings:normal;font-feature-settings:normal;font-variant:normal;font-weight:400;letter-spacing:normal;line-height:25.6px;-webkit-text-decoration:none solid #31333f;text-decoration:none solid #31333f;text-align:start;text-indent:0;text-transform:none;vertical-align:middle;white-space:normal;word-spacing:0;background-attachment:scroll;background-color:#f9f9fb;background-image:none;background-position:50% 50%;background-repeat:no-repeat;color:#31333f;height:20px;width:20px;margin-right:4px;border:2px solid rgba(49,51,63,.4);min-width:auto;position:static;top:4px;bottom:auto;right:auto;left:4px;float:none;display:inline-flex;clear:none;z-index:auto;list-style-image:none;list-style-type:disc;list-style-position:outside;border-collapse:separate;border-spacing:0;caption-side:top;empty-cells:show;table-layout:auto;overflow:visible;cursor:pointer;visibility:visible;-webkit-transform:none;transform:none;outline-offset:0;box-sizing:border-box;resize:none;text-shadow:none;text-overflow:clip;word-wrap:normal;box-shadow:none;border-top-left-radius:4px;border-top-right-radius:4px;border-bottom-left-radius:4px;border-bottom-right-radius:4px}
/*# sourceMappingURL=main.96dbfc01.chunk.css.map */