self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "bc1474440fd7b27bc15af46a18854ab8",
    "url": "./index.html"
  },
  {
    "revision": "9dbfefa1bf50f84aea96",
    "url": "./static/css/main.96dbfc01.chunk.css"
  },
  {
    "revision": "c303d2cb52daa2cfeba1",
    "url": "./static/js/2.27fb2a95.chunk.js"
  },
  {
    "revision": "3fc7fb5bfeeec1534560a2c962e360a7",
    "url": "./static/js/2.27fb2a95.chunk.js.LICENSE.txt"
  },
  {
    "revision": "9dbfefa1bf50f84aea96",
    "url": "./static/js/main.ddfac3eb.chunk.js"
  },
  {
    "revision": "7c26bca7e16783d14d15",
    "url": "./static/js/runtime-main.11ec9aca.js"
  }
]);