self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "78608a303d507cea9f9137b9c00f3962",
    "url": "./index.html"
  },
  {
    "revision": "7404e33ea2a6d1b7b6a6",
    "url": "./static/css/main.96dbfc01.chunk.css"
  },
  {
    "revision": "8e101a55db503878592d",
    "url": "./static/js/2.671b2fa3.chunk.js"
  },
  {
    "revision": "3fc7fb5bfeeec1534560a2c962e360a7",
    "url": "./static/js/2.671b2fa3.chunk.js.LICENSE.txt"
  },
  {
    "revision": "7404e33ea2a6d1b7b6a6",
    "url": "./static/js/main.59e9064c.chunk.js"
  },
  {
    "revision": "7c26bca7e16783d14d15",
    "url": "./static/js/runtime-main.11ec9aca.js"
  }
]);