(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{17:function(n,t,e){n.exports={poButton:"style_poButton__3x8Ka"}},18:function(n,t,e){n.exports=e(26)},26:function(n,t,e){"use strict";e.r(t);var o=e(8),a=e.n(o),c=e(15),r=e.n(c),i=e(6),s=e(0),m=e(1),p=e(2),l=e(3),u=e(13),d=e(17),g=e.n(d),O=function(n){Object(p.a)(e,n);var t=Object(l.a)(e);function e(n){var o;Object(m.a)(this,e),(o=t.call(this,n)).render=function(){return a.a.createElement("span",null,a.a.createElement("button",{className:g.a.poButton,onClick:o._onClicked,disabled:o.props.disabled,onFocus:o._onFocus,onBlur:o._onBlur},a.a.createElement("span",null,a.a.createElement("img",{style:{margin:"0px 3px 2px 0px"},src:"./img/pollination.png",alt:"logo"})),"Run Command"))},o._onClicked=function(){if("undefined"!=typeof window.parent.chrome){if("undefined"==typeof window.parent.chrome.webview)return void console.log("[POLLINATION-DEBUG]: webview not found.");var n={action:"RunCommand",commandString:o.props.args.commandString,commandOptions:o.props.args.commandOptions},t=JSON.stringify(n);window.parent.chrome.webview.postMessage(t),o.setState((function(t){return Object(i.a)(Object(i.a)({},t),{},{commandString:n.commandString,commandOptions:n.commandOptions})}),(function(){return u.a.setComponentValue(o.state.action)})),console.log("[POLLINATION-DEBUG]: JSON string sent.")}else console.log("[POLLINATION-DEBUG]: chrome not found.")},o._onFocus=function(){o.setState({isFocused:!0})},o._onBlur=function(){o.setState({isFocused:!1})};var c={action:"RunCommand",commandString:o.props.args.commandString,commandOptions:o.props.args.commandOptions};return o.state=Object(i.a)({},c),o}return Object(s.a)(e)}(u.b),f=Object(u.c)(O);r.a.render(a.a.createElement(a.a.StrictMode,null,a.a.createElement(f,null)),document.getElementById("root"))}},[[18,1,2]]]);
//# sourceMappingURL=main.fc66901c.chunk.js.map