(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{17:function(e,t,n){e.exports={poButton:"style_poButton__3x8Ka"}},18:function(e,t,n){e.exports=n(26)},26:function(e,t,n){"use strict";n.r(t);var o=n(8),a=n.n(o),r=n(15),s=n.n(r),i=n(6),c=n(0),p=n(1),l=n(2),u=n(3),d=n(13),m=n(17),g=n.n(m),f=function(e){Object(l.a)(n,e);var t=Object(u.a)(n);function n(e){var o;Object(p.a)(this,n),(o=t.call(this,e)).render=function(){var e={BakeGeometry:"Bake Geometry",ClearGeometry:"Clear Geometry",DrawGeometry:"Draw Geometry",DisableDraw:"Disable Draw",BakePollinationModel:"Bake Pollination Model"};return a.a.createElement("span",null,o.props.args.action in e&&a.a.createElement("button",{className:g.a.poButton,onClick:o._onClicked,disabled:o.props.disabled,onFocus:o._onFocus,onBlur:o._onBlur},a.a.createElement("span",null,a.a.createElement("img",{style:{margin:"0px 3px 2px 0px"},src:"./img/pollination.png",alt:"logo"})),e[o.props.args.action]))},o._onClicked=function(){if("undefined"!=typeof window.parent.chrome){if("undefined"==typeof window.parent.chrome.webview)return void console.log("[POLLINATION-DEBUG]: webview not found.");var e={action:o.props.args.action,data:o.props.args.data,uniqueId:o.props.args.uniqueId,options:o.props.args.options},t=JSON.stringify(e);window.parent.chrome.webview.postMessage(t),o.setState((function(t){return Object(i.a)(Object(i.a)({},t),{},{action:e.action,data:e.data,uniqueId:e.uniqueId,options:e.options})}),(function(){return d.a.setComponentValue(o.state.action)})),console.log("[POLLINATION-DEBUG]: JSON string sent.")}else console.log("[POLLINATION-DEBUG]: chrome not found.")},o._onFocus=function(){o.setState({isFocused:!0})},o._onBlur=function(){o.setState({isFocused:!1})};var r={action:o.props.args.action,data:o.props.args.data,uniqueId:o.props.args.uniqueId,options:o.props.args.options};return o.state=Object(i.a)({},r),o}return Object(c.a)(n)}(d.b),b=Object(d.c)(f);s.a.render(a.a.createElement(a.a.StrictMode,null,a.a.createElement(b,null)),document.getElementById("root"))}},[[18,1,2]]]);
//# sourceMappingURL=main.d71aa30a.chunk.js.map