self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "bcdb40634f2dedf62796665279aa5631",
    "url": "./index.html"
  },
  {
    "revision": "59e0c51aa5ea8d1d5ff3",
    "url": "./static/css/main.96dbfc01.chunk.css"
  },
  {
    "revision": "3dd9ff6525120eebfa1b",
    "url": "./static/js/2.0fba02d9.chunk.js"
  },
  {
    "revision": "3fc7fb5bfeeec1534560a2c962e360a7",
    "url": "./static/js/2.0fba02d9.chunk.js.LICENSE.txt"
  },
  {
    "revision": "59e0c51aa5ea8d1d5ff3",
    "url": "./static/js/main.4cdabd50.chunk.js"
  },
  {
    "revision": "7c26bca7e16783d14d15",
    "url": "./static/js/runtime-main.11ec9aca.js"
  }
]);